@@ -5,12 +5,7 @@ from flexs.baselines.explorers.bo import BO, GPR_BO  # noqa: F401
 from flexs.baselines.explorers.cbas_dbas import VAE, CbAS  # noqa: F401
 from flexs.baselines.explorers.cmaes import CMAES  # noqa: F401
 from flexs.baselines.explorers.dqn import DQN  # noqa: F401
-from flexs.baselines.explorers.dyna_ppo import (  # noqa: F401
-    DynaPPO,
-    DynaPPOMutative,
-)
-from flexs.baselines.explorers.genetic_algorithm import (  # noqa: F401
-    GeneticAlgorithm,
-)
+from flexs.baselines.explorers.dyna_ppo import DynaPPO, DynaPPOMutative  # noqa: F401
+from flexs.baselines.explorers.genetic_algorithm import GeneticAlgorithm  # noqa: F401
 from flexs.baselines.explorers.ppo import PPO  # noqa: F401
 from flexs.baselines.explorers.random import Random  # noqa: F401
