@@ -1,8 +1,6 @@
 """FLEXS landscapes module."""
 from flexs.landscapes import rna  # noqa: F401
-from flexs.landscapes.additive_aav_packaging import (  # noqa: F401
-    AdditiveAAVPackaging,
-)
+from flexs.landscapes.additive_aav_packaging import AdditiveAAVPackaging  # noqa: F401
 from flexs.landscapes.bert_gfp import BertGFPBrightness  # noqa: F401
 from flexs.landscapes.rna import RNABinding  # noqa: F401
 from flexs.landscapes.rosetta import RosettaFolding  # noqa: F401
